@@ -9,6 +9,7 @@ from lostc import collection as lcc
 
 import minio.error
 from minio import Minio
+from minio.commonconfig import CopySource
 from suanpan import api, asyncio, g
 from suanpan import path as spath
 from suanpan import runtime
@@ -156,7 +157,9 @@ class Storage(base.Storage):
         asyncio.map(
             spath.remove, restFiles, pbar=quiet, desc="Removing Rest Files",
         )
-        spath.removeEmptyFolders(path)
+        # only if the `path` folder is getPathInTempStore, try to clear it
+        if path == self.getPathInTempStore(key):
+            spath.removeEmptyFolders(path)
         if not quiet:
             logger.debug(f"Removed empty folders in: {path}")
         # End
@@ -380,8 +383,8 @@ class Storage(base.Storage):
                 pbar.set_description("Existed")
                 return dist
 
-            sourcePath = self.delimiter + self.storagePathJoin(bucket, src)
-            self.autoRefreshToken(self.client.copy_object)(bucket, src, sourcePath)
+            # sourcePath = self.delimiter + self.storagePathJoin(bucket, src)
+            self.autoRefreshToken(self.client.copy_object)(bucket, dist, CopySource(bucket, src))
             pbar.update(fileSize)
             pbar.set_description("Copied")
             return dist
