@@ -6,7 +6,8 @@ import os
 import sys
 import traceback
 import uuid
-
+import gc
+import gevent
 import gevent.pywsgi
 import socketio
 from engineio import static_files
@@ -156,7 +157,10 @@ class Stream(
         logger.debug("Stream ALL Loop Closed")
 
         if self._exit_code != 0:
-            os._exit(self._exit_code)
+            # kill greenlet created by other modules
+            running = [obj for obj in gc.get_objects() if isinstance(obj, gevent.Greenlet) and bool(obj)]
+            gevent.killall(running)
+            sys.exit(self._exit_code)
 
     def close(self, code=0):
         self._exit_code = code
